VuiPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • VuiPluginPlatform
Implementers

Constructors

VuiPluginPlatform()
Constructs a VuiPluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onCommand Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableCommands() Future<List<String>>
Get available voice commands for current screen
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentScreen(String screenName) Future<void>
Set the current screen context for context-aware commands
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance VuiPluginPlatform
The default instance of VuiPluginPlatform to use.
getter/setter pair