MethodChannelVuiPlugin class

An implementation of VuiPluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelVuiPlugin()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
onCommand Stream<String>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableCommands() Future<List<String>>
Get available voice commands for current screen
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentScreen(String screenName) Future<void>
Set the current screen context for context-aware commands
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited